async fn init_prunable_finalized_blocks_archive<TContext>(
context: &TContext,
partition_prefix: &str,
page_cache: CacheRef,
) -> Result<Archive<TwoCap, TContext, Digest, Block>, Error>Expand description
Initialize the prunable archive that holds recently finalized blocks.
This archive only holds at most retention_blocks items at any time;
older blocks are removed by the prune step in
Hybrid.